CTFontManagerCompareFontFamilyNames

Function CTFontManagerCompareFontFamilyNames 

pub unsafe extern "C-unwind" fn CTFontManagerCompareFontFamilyNames(
    family1: NonNull<c_void>,
    family2: NonNull<c_void>,
    context: *mut c_void,
) -> CFComparisonResult
Available on crate feature CTFontManager only.
A CFComparatorFunction to compare font family names and sort them according to Apple guidelines.

This function compares font family names and sorts them in the preferred order for display in user interfaces.

Parameter family1: The first localized font family name, as CFStringRef.

Parameter family2: The second localized font family name, as CFStringRef.

Parameter context: Unused. Can be NULL.

Returns: A CFComparisonResult value indicating the sort order for the two family names. kCFComparisonResultGreaterThan if family1 is greater than family2, kCFComparisonResultLessThan if family1 is less than family2, and kCFComparisonResultEqualTo if they are equal.

Safety

  • family1 must be a valid pointer.
  • family2 must be a valid pointer.
  • context must be a valid pointer or null.