CTFontManagerCopyRegisteredFontDescriptors

Function CTFontManagerCopyRegisteredFontDescriptors 

pub unsafe extern "C-unwind" fn CTFontManagerCopyRegisteredFontDescriptors(
    scope: CTFontManagerScope,
    enabled: bool,
) -> CFRetained<CFArray>
Available on crate feature CTFontManager only.
Returns the font descriptors that were registered with the font manager.

In the case the persistent scope is specified, only macOS can return fonts registered by any process. Other platforms can only return font descriptors registered by the application’s process.

Parameter scope: Scope constant defining the availability and lifetime of the registration. See scope constants for more details.

Parameter enabled: Boolean value indicating if the caller is interested in registered font descriptors that are enabled or disabled.

Returns: Array of of font descriptors registered by the application. Array may be empty if nothing is registered.