pub unsafe extern "C-unwind" fn CTFontManagerCreateFontDescriptorsFromData(
data: &CFData,
) -> CFRetained<CFArray>Available on crate feature
CTFontManager only.Expand description
Returns an array of font descriptors for the fonts in the supplied data. Note: the font descriptors are not available through font descriptor matching.
Parameter data: A CFData containing font data.
Returns: An array of font descriptors. This can be an empty array in the event of invalid or unsupported font data.