CTFontManagerCreateFontDescriptorsFromURL

Function CTFontManagerCreateFontDescriptorsFromURL 

pub unsafe extern "C-unwind" fn CTFontManagerCreateFontDescriptorsFromURL(
    file_url: &CFURL,
) -> Option<CFRetained<CFArray>>
Available on crate feature CTFontManager only.
Returns an array of font descriptors representing each of the fonts in the specified URL. Note: these font descriptors are not available through font descriptor matching.

Parameter fileURL: A file system URL referencing a valid font file.

Returns: An array of CTFontDescriptors or NULL if there are no valid fonts.