pub unsafe extern "C-unwind" fn CTFontManagerRequestFonts(
font_descriptors: &CFArray,
completion_handler: &DynBlock<dyn Fn(NonNull<CFArray>)>,
)CTFontManager and block2 only.Expand description
Resolves font descriptors specified on input. On iOS only, if the font descriptors cannot be found, the user is presented with a dialog indicating fonts that could not be resolved. The user may optionally be provided with a way to resolve the missing fonts if the font manager has a way to enable them.
On iOS, fonts registered by font provider applications in the persistent scope are not automatically available to other applications. Client applications must call this function to make the requested fonts available for font descriptor matching.
Parameter fontDescriptors: Array of font descriptors to make available to the process. Keys used to describe the fonts may be a combination of: kCTFontNameAttribute, kCTFontFamilyNameAttribute, or kCTFontRegistrationUserInfoAttribute.
Parameter completionHandler: Block called after request operation completes. Block takes a single parameter containing an array of those descriptors that could not be resolved/found. The array can be empty if all descriptors were resolved.
Safety
font_descriptors generic must be of the correct type.