CTFontManagerUnregisterFontsForURL

Function CTFontManagerUnregisterFontsForURL 

pub unsafe extern "C-unwind" fn CTFontManagerUnregisterFontsForURL(
    font_url: &CFURL,
    scope: CTFontManagerScope,
    error: *mut *mut CFError,
) -> bool
Available on crate feature CTFontManager only.
Unregisters fonts from the specified font URL with the font manager. Unregistered fonts do not participate in font descriptor matching. iOS note: only fonts registered with CTFontManagerRegisterFontsForURL or CTFontManagerRegisterFontsForURLs can be unregistered with this API.

Parameter fontURL: Font URL.

Parameter scope: Scope constant defining the availability and lifetime of the registration. Should match the scope the fonts are registered in. See scope constants for more details.

Parameter error: Pointer to receive CFError in the case of failed unregistration.

Returns: Returns true if unregistration of the fonts was successful.

Safety

error must be a valid pointer or null.