CTFontManagerUnregisterGraphicsFont

Function CTFontManagerUnregisterGraphicsFont 

pub unsafe extern "C-unwind" fn CTFontManagerUnregisterGraphicsFont(
    font: &CGFont,
    error: *mut *mut CFError,
) -> bool
๐Ÿ‘ŽDeprecated: Use the API corresponding to the one used to register the font
Available on crate features CTFontManager and objc2-core-graphics only.
Unregisters the specified graphics font with the font manager. Unregistered fonts do not participate in font descriptor matching.

Parameter font: Graphics font to be unregistered.

Parameter error: Pointer to receive CFError in the case of failed unregistration.

Returns: Returns true if unregistration of the font was successful.

Safety

error must be a valid pointer or null.