pub unsafe extern "C-unwind" fn CTFontManagerEnableFontDescriptors(
descriptors: &CFArray,
enable: bool,
)Available on crate feature
CTFontManager only.Expand description
Enables or disables the matching font descriptors for font descriptor matching.
Parameter descriptors: Array of font descriptors.
Parameter enable: Boolean value indicating whether the fonts matching descriptors should be enabled for font descriptor matching.
Safety
descriptors generic must be of the correct type.