pub unsafe extern "C-unwind" fn CTFontManagerRegisterFontsForURL(
font_url: &CFURL,
scope: CTFontManagerScope,
error: *mut *mut CFError,
) -> boolAvailable on crate feature
CTFontManager only.Expand description
Registers fonts from the specified font URL with the font manager. Registered fonts participate in font descriptor matching.
Parameter fontURL: A file URL for the font or collection (TTC or OTC) to be registered. Once fonts have been registered from a file, it shouldn’t be moved or renamed.
Parameter scope: Scope constant defining the availability and lifetime of the registration. See scope constants for more details.
Parameter error: Pointer to receive CFError in the case of failed registration.
Returns: Returns true if registration of the fonts was successful.
Safety
error must be a valid pointer or null.