pub unsafe extern "C-unwind" fn CTFontManagerRegisterFontsForURLs(
font_ur_ls: &CFArray,
scope: CTFontManagerScope,
errors: *mut *const CFArray,
) -> boolCTFontManager only.Expand description
Registers fonts from the specified font URLs with the font manager. Registered fonts are discoverable through font descriptor matching.
Parameter fontURLs: An array of file URLs for the fonts or collections (TTC or OTC) to be registered. Once fonts have been registered from a file, it shouldn’t be moved or renamed.
Parameter scope: Scope constant defining the availability and lifetime of the registration. See scope constants for more details.
Parameter errors: Pointer to CFArrayRef to receive array of CFError references. Each error will contain a CFArray of font URLs corresponding to kCTFontManagerErrorFontURLsKey. These URLs represent the font files that caused the error, and were not successfully registered. Must be released by caller. Can be NULL.
Returns: Returns true if registration of all font URLs was successful. Otherwise false.
Safety
font_ur_lsgeneric must be of the correct type.errorsmust be a valid pointer or null.