pub unsafe extern "C-unwind" fn CTFontManagerUnregisterFontsForURLs(
font_ur_ls: &CFArray,
scope: CTFontManagerScope,
errors: *mut *const CFArray,
) -> boolCTFontManager only.Expand description
Unregisters fonts from the specified font URLs with the font manager. Unregistered fonts do not participate in font descriptor matching. iOS note: only fonts registered with CTFontManagerRegisterFontsForURL or CTFontManagerRegisterFontsForURLs can be unregistered with this API.
Parameter fontURLs: Array of font URLs.
Parameter scope: Scope constant defining the availability and lifetime of the registration. Should match the scope the fonts are registered in. See scope constants for more details.
Parameter errors: Pointer to CFArrayRef to receive array of CFError references. Each error will contain a CFArray of font URLs corresponding to kCTFontManagerErrorFontURLsKey. These URLs represent the font files that caused the error, and were not successfully unregistered. Must be released by caller. Can be NULL.
Returns: Returns true if unregistration of all font URLs was successful. Otherwise false.
Safety
font_ur_lsgeneric must be of the correct type.errorsmust be a valid pointer or null.